# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"say_hello": "00_core.ipynb"}

modules = ["core.py"]

doc_url = "https://pnmartinez.github.io/nbdevsetup/"

git_url = "https://github.com/pnmartinez/nbdevsetup/tree/master/"

def custom_doc_links(name): return None
